/* Exporta os dados da movimentao do caixa para o financeiro*/
create or replace PROCEDURE EXPORTA_PDV_FINANC(
   P_CDEMPRESA    IN NOTAFISCAL.CDEMPRESA%TYPE,      /*Cod. da empresa*/
   P_CDFILIPROC   IN NOTAFISCAL.CDFILIAL%TYPE,       /*Cod. da filial de processamento*/
   P_CDOPERADOR   IN BAIXARECEBIDA.CDOPERADOR%TYPE,  /*Cod do operador*/
   P_FILIORIGEM   IN NOTAFISCAL.CDFILIAL%TYPE,       /*Cod. da filial de origem*/
   P_DTMOVIMCAIXA IN MOVCAIXA.DTMOVIMCAIXA%TYPE,     /*Data da movimentao do caixa*/
   P_DTVENCIMENTO IN CONTARECEBER.DTORIGVENREC%TYPE, /*Data de vencimento do lanamento financ.*/
   P_CDTIPORECE   IN MOVCAIXA.CDTIPORECE%TYPE,       /*Tipo de recebimento*/
   P_NRCHEQUEVEND IN MOVCAIXA.NRCHEQUEVEND%TYPE,     /*Num. do cheque*/
   P_CDBANCHEQVEN IN MOVCAIXA.CDBANCHEQVEN%TYPE,     /*Cod. do banco do cheque*/
   P_CDAGECHEQVEN IN MOVCAIXA.CDAGECHEQVEN%TYPE,     /*Cod. da agencia do cheque*/
   P_CDCNTCHEQVEN IN MOVCAIXA.CDCNTCHEQVEN%TYPE,     /*Cod. do cheque*/
   P_NRINSJURCHEQ IN MOVCAIXA.NRINSJURCHEQ%TYPE,     /*Num. do CPF*/
   P_VRMOVIVEND   IN MOVCAIXA.VRMOVIVEND%TYPE,       /*Valor da movimento*/
   P_CDCLIENTE    IN NOTAFISCAL.CDCLIENTE%TYPE,      /*Cdigo do cliente*/
   P_CDVENDEDOR   IN NOTAFISCAL.CDVENDEDOR%TYPE,     /*Cdigo do vendedor(opcional)*/
   P_CDTIPOOPER   IN NOTAFISCAL.CDTIPOOPER%TYPE,     /*Tipo de operao*/
   P_CDSERIE      IN NOTAFISCAL.CDSERIE%TYPE,        /*Srie de sada*/
   P_SOMATORIO    IN VARCHAR2,                       /*Tipo de somatrio*/
   P_QTPARCELAS   IN FLOAT)                          /*Quantidade de parcelas*/
AS
   V_NRLANCTONF    VARCHAR2(20);
   V_NRLANBOL      VARCHAR2(20);
   V_IDTIPORECE    TIPORECE.IDTIPORECE%TYPE;
   V_DESCCONTA     TIPOCTRECEBER.DSTPCTRECEB%TYPE;
   V_CDTPAJUSTE    TIPORECE.CDAJTXADMREC%TYPE;
   V_VRPETAXA      TIPORECE.VRTAXAADMI%TYPE;
   V_VRAJUSTE      AJCTRECEBER.VRAJUSTEREC%TYPE;
   V_CDCONTCORR    PARAMEMPRESA.CDREDUGBEMPR%TYPE;
   V_CDTIPOBAIXA   PARAMEMPRESA.CDTPBAIXAREC%TYPE;
   V_NMRAZSOCCLIE  CLIENTE.NMRAZSOCCLIE%TYPE;
   V_NRINSJURCLIE  CLIENTE.NRINSJURCLIE%TYPE;
   V_CDCLIENTE     NOTAFISCAL.CDCLIENTE%TYPE;
   V_QTPARCELAS    FLOAT;
BEGIN
   V_QTPARCELAS := P_QTPARCELAS;
   IF (V_QTPARCELAS IS NULL) OR (V_QTPARCELAS = 0) THEN
      V_QTPARCELAS := 1;
   END IF;
   /* Busca o nmero do lanamento da NF*/
   NOVO_CODIGO('LANCNF/FILIAL' || P_CDFILIPROC, V_NRLANCTONF);
   V_NRLANCTONF := SUBSTR(V_NRLANCTONF, 11, 10);

   /* Busca o nmero do boleto */
   NOVO_CODIGO('BOLETRECEBER' || P_CDFILIPROC, V_NRLANBOL, V_QTPARCELAS);
   V_NRLANBOL := SUBSTR(V_NRLANBOL, 11, 10);

   /*Verifica se existe taxa administrativa*/
   BEGIN
      SELECT MAX(TGER.IDTIPORECE), MAX(TGER.CDAJTXADMREC), NVL(MAX(TFIL.VRTAXAADMFIL), MAX(TGER.VRTAXAADMI))
      INTO V_IDTIPORECE, V_CDTPAJUSTE, V_VRPETAXA
      FROM TIPORECE TGER, TIPORECEFILIAL TFIL
      WHERE TGER.CDTIPORECE = P_CDTIPORECE
         AND TGER.CDTIPORECE = TFIL.CDTIPORECE(+)
         AND TFIL.CDFILIAL(+) = P_FILIORIGEM;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN V_IDTIPORECE := ''; V_CDTPAJUSTE := ''; V_VRPETAXA := 0;
   END;

   V_VRAJUSTE := 0;
   IF (V_CDTPAJUSTE IS NOT NULL) AND (V_VRPETAXA > 0)  THEN
      V_VRAJUSTE := ROUND(V_VRPETAXA * P_VRMOVIVEND / 100, 2);
   END IF;

   V_CDCONTCORR := '';
   V_CDTIPOBAIXA := '';

   IF V_IDTIPORECE IN ('3','4') THEN
      IF V_IDTIPORECE = '4' THEN
         SELECT MAX(CDREDUCONT), MAX(CDTPBAIXAREC)
         INTO V_CDCONTCORR, V_CDTIPOBAIXA
         FROM PARAVEND
         WHERE CDFILIAL = P_FILIORIGEM;
      END IF;
 
      IF (V_CDCONTCORR IS NULL) AND (V_CDTIPOBAIXA IS NULL)  THEN
         SELECT MAX(CDREDUCONT), MAX(CDTPBAIXAREC)
         INTO V_CDCONTCORR, V_CDTIPOBAIXA
         FROM TIPORECE
         WHERE CDTIPORECE = P_CDTIPORECE;
      END IF;
   END IF;

   SELECT MAX(NRINSJURCLIE), MAX(NMRAZSOCCLIE)
   INTO V_NRINSJURCLIE, V_NMRAZSOCCLIE
   FROM CLIENTE
   WHERE CDCLIENTE = P_CDCLIENTE;

   IF P_NRCHEQUEVEND IS NOT NULL THEN
      INSERT INTO CHEQUERECE
     (NRCHEQUERECE, CDBANCHEQREC, CDAGECHEQREC, CDCNTCHEQREC,
      VRCHEQUERECE, NRCOMCHEQREC, DTRECECHEQUE, DTVENCHEQREC,
      CDCLIENTE,    IDTIPCHEQREC, NRCEDCHEQREC, NMCEDCHEQREC,
      IDSITCHEQREC, CDREDUCONT, CDEMPRESA)
      VALUES
     (P_NRCHEQUEVEND, P_CDBANCHEQVEN, P_CDAGECHEQVEN, P_CDCNTCHEQVEN,
      P_VRMOVIVEND, '001', P_DTMOVIMCAIXA, P_DTVENCIMENTO,
      P_CDCLIENTE, 'P', V_NRINSJURCLIE, V_NMRAZSOCCLIE,
      'A', V_CDCONTCORR, P_CDEMPRESA);
   END IF;

   V_DESCCONTA := 'MOVIMENTAO DE CAIXA';

   GERA_CONTA(
      'S',
      P_CDEMPRESA,
      P_CDFILIPROC,
      P_FILIORIGEM,
      V_NRLANCTONF,
      V_NRLANBOL,
      P_VRMOVIVEND, /*Valor da movimentao*/
      P_CDTIPOOPER,
      P_CDSERIE,
      'C', /*IDORIGDEST: Cliente*/
      P_CDCLIENTE, /*Cliente padro*/
      P_DTMOVIMCAIXA,   /*DTEMISSAO*/
      P_DTMOVIMCAIXA,  /*DTENTRSAID*/
      'A', /*Status da nota*/
      P_CDVENDEDOR,  /*Vendedor*/
      P_DTMOVIMCAIXA,    /*DTLANCNF*/
      P_DTVENCIMENTO, /*DTMOVCAIXA + Qtde. dias para recebimento*/
      P_CDTIPORECE,  /*Tipo de Recebimento*/
      V_DESCCONTA, /*Descrio da conta*/
      P_NRCHEQUEVEND,  /*dados do cheque*/
      P_CDBANCHEQVEN,
      P_CDAGECHEQVEN,
      P_CDCNTCHEQVEN,
      P_NRINSJURCHEQ,
      'A', /*Status da conta*/
      V_CDTPAJUSTE,
      V_VRAJUSTE,
      P_CDOPERADOR,
      V_QTPARCELAS);

   IF P_NRCHEQUEVEND IS NOT NULL THEN
       UPDATE MOVCAIXA
       SET NRLANCTONF = V_NRLANCTONF,
           CDFILIALNF = P_CDFILIPROC
       WHERE CDFILIAL = P_FILIORIGEM AND
             DTMOVIMCAIXA = P_DTMOVIMCAIXA AND
             CDTIPORECE = P_CDTIPORECE AND
             NRCHEQUEVEND = P_NRCHEQUEVEND AND
             CDBANCHEQVEN = P_CDBANCHEQVEN AND
             CDAGECHEQVEN = P_CDAGECHEQVEN AND
             CDCNTCHEQVEN = P_CDCNTCHEQVEN AND
             NRLANCTONF IS NULL AND
            (NRINSJURCHEQ = P_NRINSJURCHEQ OR NRINSJURCHEQ IS NULL);
    ELSE

      IF (P_SOMATORIO = '1') THEN /* Verifica o tipo de somatrio da tela */
         UPDATE MOVCAIXA M
         SET NRLANCTONF = V_NRLANCTONF,
             CDFILIALNF = P_CDFILIPROC
         WHERE (NRSEQVENDA IN (SELECT M.NRSEQVENDA
                                FROM MOVCAIXA M, VENDA V
                               WHERE M.CDFILIAL = P_FILIORIGEM
                                 AND M.DTMOVIMCAIXA = P_DTMOVIMCAIXA
                                 AND M.CDTIPORECE = P_CDTIPORECE
                                 AND V.CDCLIENTE = P_CDCLIENTE
                                 AND M.CDFILIAL = V.CDFILIAL
                                 AND M.CDCAIXA = V.CDCAIXA
                                 AND M.NRSEQVENDA = V.NRSEQVENDA))
           AND M.CDFILIAL = P_FILIORIGEM
           AND M.DTMOVIMCAIXA = P_DTMOVIMCAIXA
           AND M.CDTIPORECE = P_CDTIPORECE
           AND NRLANCTONF IS NULL
           AND QTPARCRECEB = P_QTPARCELAS;
      ELSE
         UPDATE MOVCAIXA
         SET NRLANCTONF = V_NRLANCTONF,
             CDFILIALNF = P_CDFILIPROC
         WHERE CDFILIAL = P_FILIORIGEM
           AND DTMOVIMCAIXA = P_DTMOVIMCAIXA
           AND CDTIPORECE = P_CDTIPORECE
           AND NRLANCTONF IS NULL
           AND QTPARCRECEB = P_QTPARCELAS;
      END IF;
    END IF;

   /*Se o tipo de recebimento for dinheiro  gerada a baixa*/
   IF V_IDTIPORECE IN ('3','4') THEN
      GERA_BAIXA('S', P_CDEMPRESA, P_CDFILIPROC,
                 V_NRLANBOL, P_CDFILIPROC, P_DTMOVIMCAIXA,
                 V_CDCONTCORR, V_CDTIPOBAIXA, P_CDOPERADOR);
   END IF;
END;
/


-- VERSAO --
BEGIN ATUVEROBJ('EXPORTA_PDV_FINANC','5.07.009'); END;
/

